// Adobe Illustrator Script to Delete Locked Layers in AI Files from a Selected Folder

// Function to delete locked layers recursively
function deleteLockedLayers(layer) {
  // Check if the current layer is locked and has a specific name
  if (layer.locked && (layer.name === "Group" || layer.name === "watermark")) {
    layer.remove();
  } else {
    // Loop through sub-layers and delete locked ones
    for (var i = layer.layers.length - 1; i >= 0; i--) {
      deleteLockedLayers(layer.layers[i]);
    }
  }
}

// Prompt the user to select a folder containing AI files
var folder = Folder.selectDialog("Select the folder containing AI files");

if (folder) {
  // Get a list of AI files in the selected folder
  var files = folder.getFiles("*.ai");

  if (files.length === 0) {
    alert("No AI files found in the selected folder.");
  } else {
    // Loop through each AI file
    for (var i = 0; i < files.length; i++) {
      var file = new File(files[i]);
      app.open(file);

      // Get the active document
      var doc = app.activeDocument;

      // Start deleting locked layers from the top-level layers
      for (var j = doc.layers.length - 1; j >= 0; j--) {
        deleteLockedLayers(doc.layers[j]);
      }

      // Save and close the modified document
      doc.save();
      doc.close();
    }

    // Notify when the process is complete
    alert("Locked layers named 'Group' and 'watermark' have been deleted from AI files in the selected folder.");
  }
} else {
  alert("No folder selected.");
}
