// Function to resize the artboard and artwork to 600x600
function resizeArtboardAndArtwork(doc) {
  try {
    // Set the desired size for the artboard and artwork
    var artboardWidth = 600;
    var artboardHeight = 600;

    // Get the active artboard index
    var activeABIndex = doc.artboards.getActiveArtboardIndex();
    var activeAB = doc.artboards[activeABIndex];

    // Get the bounds of the artwork (visible content) on the artboard
    var artBounds = doc.visibleBounds;
    var artWidth = artBounds[2] - artBounds[0];
    var artHeight = artBounds[1] - artBounds[3];

    // Calculate the scale factor to fit the artwork within the new artboard dimensions
    var scaleX = artboardWidth / artWidth;
    var scaleY = artboardHeight / artHeight;
    var scaleFactor = Math.min(scaleX, scaleY);

    // Center the artwork within the artboard
    var offsetX = (artboardWidth - artWidth * scaleFactor) / 2;
    var offsetY = (artboardHeight - artHeight * scaleFactor) / 2;

    // Resize and reposition the artwork
    doc.selectObjectsOnActiveArtboard(); // Select all objects on the active artboard
    var selection = doc.selection;
    for (var i = 0; i < selection.length; i++) {
      var item = selection[i];
      item.left = (item.left - artBounds[0]) * scaleFactor + offsetX;
      item.top = (item.top - artBounds[1]) * scaleFactor + offsetY;
      item.width *= scaleFactor;
      item.height *= scaleFactor;
    }
    doc.selection = null; // Deselect all objects after resizing

    // Resize the artboard
    activeAB.artboardRect = [
      0,
      0,
      artboardWidth,
      -artboardHeight // Minus sign to set height as a negative value (Illustrator coordinate system)
    ];
  } catch (error) {
    alert("Error occurred while resizing the artboard and artwork: " + error);
  }
}

// Main function to process files in a selected folder
function processFilesInFolder() {
  var dir = Folder.selectDialog("Select a folder containing .ai files");
  if (dir) {
    var files = dir.getFiles("*.ai");
    for (var i = 0; i < files.length; i++) {
      var file = files[i];
      var doc = app.open(file);

      // Resize the artboard and artwork
      resizeArtboardAndArtwork(doc);

      // Save and close the file
      var saveOptions = new IllustratorSaveOptions();
      saveOptions.compatibility = Compatibility.ILLUSTRATOR17; // Use the Illustrator CC 2015 format (change if needed)
      saveOptions.flattenOutput = OutputFlattening.PRESERVEAPPEARANCE;
      saveOptions.pdfCompatible = true;
      var newFile = new File(dir + "/resized_" + file.name); // Save with a new name
      doc.saveAs(newFile, saveOptions);
      doc.close(SaveOptions.DONOTSAVECHANGES);
    }
    alert("Task completed successfully!");
  } else {
    alert("No folder selected. Task aborted.");
  }
}

// Call the main function to start processing files
processFilesInFolder();