// Function to delete empty layers in the active document
function deleteEmptyLayers(doc) {
  for (var i = doc.layers.length - 1; i >= 0; i--) {
    var layer = doc.layers[i];
    if (layer.pageItems.length === 0 && layer.layers.length === 0) {
      layer.remove();
    }
  }
}

// Function to process the active document
function processDocument() {
  try {
    var doc = app.activeDocument;

    // Delete empty layers
    deleteEmptyLayers(doc);

    // Save and close the file
    var saveOptions = new IllustratorSaveOptions();
    saveOptions.compatibility = Compatibility.ILLUSTRATOR17; // Use the Illustrator CC 2015 format (change if needed)
    saveOptions.flattenOutput = OutputFlattening.PRESERVEAPPEARANCE;
    saveOptions.pdfCompatible = true;
    doc.save();
    doc.close(SaveOptions.DONOTSAVECHANGES);
  } catch (error) {
    alert("Error occurred while processing the document: " + error);
  }
}

// Function to process files in a selected folder
function processFilesInFolder() {
  var dir = Folder.selectDialog("Select a folder containing .ai files");
  if (dir) {
    var files = dir.getFiles("*.ai");
    for (var i = 0; i < files.length; i++) {
      var file = files[i];
      var doc = app.open(file);

      // Process the document (delete empty layers)
      processDocument();

      // Save the file (original file will be overwritten)
      doc.save();

      // Close the document without saving any additional changes
      doc.close(SaveOptions.DONOTSAVECHANGES);
    }
    alert("Task completed successfully!");
  } else {
    alert("No folder selected. Task aborted.");
  }
}

// Call the main function to start processing files
processFilesInFolder();
