// Function to resize the artwork width to 900px while maintaining aspect ratio
function resizeArtwork(doc) {
  try {
    var targetWidth = 900; // Target width in pixels

    // Select all objects on the active artboard
    doc.selectObjectsOnActiveArtboard();
    var selection = doc.selection;

    // Loop through selected objects and resize width while maintaining aspect ratio
    for (var i = 0; i < selection.length; i++) {
      var item = selection[i];
      var currentWidth = item.width;
      var currentHeight = item.height;
      var aspectRatio = currentWidth / currentHeight;

      // Calculate new width and height based on target width
      var newWidth = targetWidth;
      var newHeight = newWidth / aspectRatio;

      // Resize object width while maintaining aspect ratio
      item.width = newWidth;
      item.height = newHeight;
    }

    doc.selection = null; // Deselect all objects after resizing
  } catch (error) {
    alert("Error occurred while resizing the artwork: " + error);
  }
}

// Main function to process files in a selected folder
function processFilesInFolder() {
  var dir = Folder.selectDialog("Select a folder containing .ai files");
  if (dir) {
    var files = dir.getFiles("*.ai");
    for (var i = 0; i < files.length; i++) {
      var file = files[i];
      var doc = app.open(file);

      // Resize the artwork width
      resizeArtwork(doc);

      // Save and close the file
      var saveOptions = new IllustratorSaveOptions();
      saveOptions.compatibility = Compatibility.ILLUSTRATOR17; // Use the Illustrator CC 2015 format (change if needed)
      saveOptions.flattenOutput = OutputFlattening.PRESERVEAPPEARANCE;
      saveOptions.pdfCompatible = true;
      var newFile = new File(dir + "/resized_" + file.name); // Save with a new name
      doc.saveAs(newFile, saveOptions);
      doc.close(SaveOptions.DONOTSAVECHANGES);
    }
    alert("Task completed successfully!");
  } else {
    alert("No folder selected. Task aborted.");
  }
}

// Call the main function to start processing files
processFilesInFolder();
